bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 29. Aventiure
___________________________________________________ #### Aventv wie Hagene vn– Volker vor Chriemh' sal sazen
| ### <Do> schieden sich die zwene rechen lobelich ### Hagen von Tronege vn– ovch her Dietrich ### do blicht vber ahsel der Guntheres man ### nach einem hergesellen den er vil schiere do gewan
###### 1800 | ### Er sach den videlære bi Giselhere sten ### Volchern den vil chvenen den bat er mit im gen ### wander vil wol erchande den sinen grimmen mvot ### er was an allen tvgenden ein ritter chven vn– 'gvot
###### 1801 | ### Noch liezen si die herren vfem hove sten ### niwan si einen zwene di sach man dannen gen ### vber den hof vil verre fvr ein palas wit ### die vzerwelten beide vorhten niemannes nit
###### 1802 | ### Si gesazen vor dem hvose gegen eime sal ### der was <Chriemhilde> vf eine banch zetal ### do lvohte in vor ir libe ir herlich gewant ### gnvoge die si sahen si heten gerne bechant
| ### Alsam tyer div wilden wrden gekapfet an ### die vbermveten helde von manigem Hvnen man ### do ersach si durch ein venter daz Ezeln wip ### des wart do vil trvebe der frowen Chriemh' lip
###### 1804 | ### Ez mante si ir leide weinen si began ### des hete michel wnder die Ezeln man ### waz ir so snelle ertrvbet het ir hohen mvot ### si sprach daz hat Hagene ir helde chvene vn– gvot
###### 1805 | ### Si sprachen frowe here wie ist daz geschehn ### wir habn ivch niwliche so fro <gemvot> gesehn ### niemen ist so chvene swerz iv hat getan ### heizet irz vns rechen ez sol im an sin lebn gan
###### 1806 | ### Daz wolde ich immer dienen swer reche miniv leit ### allez daz er wolde des wær ich im bereit ### ich bivt mich iv ze fvzen sprach des kuniges wip ### rechet mich an Hagene daz er verliese den lip
| ### Do garten sich ze handen wol sehzech chvner man ### dvrch der frowen liebe si wolden hin gan ### vn– wolden slahen Hagenen den vil chvnen man ### vn– oech den videlære daz wart mit rate getan
###### 1808 | ### Do div kvniginne ir schar so kleine sach ### in eime grimmen mvote si zen helden sprach ### des ir da habt gedingen des svlt ir ab gan ### iane dvrfet ir so ringe nimmer Hagenen bestan
###### 1809 | ### Swie starche vn– swie chvene der von Tronege si ### noch ist verre chvener der im da sizzet bi ### Volker der videlære der ist ein vbel man ### iane svlt ir die degene niht so lihte bestan
###### 1810 | ### Do si daz gehorten do garte sich ir mer ### driv hvndert sneller rechen div <kuneginne> her ### was des vil genoete daz si geræche ir leit ### da von wart sit den degenen vil michel arebeit be[64r]reit
###### 1811 | ### Do si nv wol gewafent ir gesinde sach ### zv den snellen degenen div kuniginne sprach ### nv bitet eine wile ir svlt noch stille stan ### ia wil ich vnder chrone mit iv zvo minen vinden gan
###### 1812 | ### Vn– hoeret itewizze waz mir hat getan ### Hagen von Tronege der Guntheres man ### ich weiz in wol so chvnen daz er mir lovgent niht ### so ist ovch mir vnmære swaz im darvmbe geschiht
| ### Do sach der videlære ein vil chvene man ### die edeln kuniginne ab einer stiegen gan ### nider vz eime hvose als er daz gesach ### der vil wise reche zvo sime hergesellen sprach
###### 1814 | ### Nv schowet frivnt Hagene wa si her gat ### div vns in vntriwen inz lant geladet hat ### ich gesach mit kuniginne nie so manigen man ### die swert enhende trvegen also striteklichen gan
###### 1815 | ### <Wizzet> ir frivnt Hagene daz si iv sin gehaz ### so rat ich iv mit triwen ir hvtet deste baz ### des libes un– der eren ia dunchet ez mich gvot ### als ich mich versinne si sint vil vbele gemvot
###### 1816 | ### Vn– sint ovch svmeliche zen brvsten also wit ### swer sin selbes hvete der tvo daz encit ### ich wæn si vnder siden die vesten prvnne tragen ### waz si da mite meinen daz kan ich niemen gesagen
| ### Do sprach in zornes mvote der vil chvne man ### ich weiz wol daz iz allez ist vf mich getan ### daz si div liehten waffen tragent an der hant ### vor den moehte ich geriten noch in der Bvrgonden lant
###### 1818 | ### Nv saget mir frivnt Volker welt ir mir gestan ### ob mit mir striten wellent die Chriemh' man ### daz lazet ir mich hoeren als liebe als ich iv si ### ich won iv immer mere mit triwen dienstlichen bi
###### 1819 | ### Ich hilf iv sicherlichen sprach do der spileman ### ob ich vns hie begegene sæhe en kunic gan ### mit allen sinen rechen die wile ich leben mvoz ### so entwiche ich iv durch vorhte vz helfe nimmer einen fvoz
###### 1820 | ### Nv lone iv got von himele vil edel Volker ### ob si mit mir striten wes bedorft ich danne mer ### sit ir mir helfen wellet als ich vernomen han ### so svln dise degene vil gewærlichen gan
###### 1821 | ### Nv sten wir von dem sedele sprach do der spileman ### si ist ein kuniginne vn– lan si fvr gan ### bieten ir die ere si ist ein edel wip ### da mit ist ovch getivret an zvhten vnser beider lip
| ### Nein dvrch mine liebe sprach aber Hagene ### so wolden lihte wænen dise degene ### daz ihz dvrch vorhte tæte vn– solde ich hin gan ### ine wil durch ir deheinen nimmer von dem sedel stan
###### 1823 | ### Ia zimt ez vns beiden zware lazen baz ### zwiv solde ich den eren der mir ist gehaz ### daz entvon ich nimmer die wil ich han den lip ### iane rvche ich waz mich hazzet des kunic Ezeln wip
###### 1824 | ### Hagene der starche der leit vber bein ### ein vil liehtez [64v]wafen vz des knopfe erschein ### ein vil liehter jaspes grvner danne ein gras ### wol erchandez Chriemh' daz ez ê Sivrides was
###### 1825 | ### Do si daz swert erchande des gie si michel not ### sin gehilze daz was gvldin div scheide porten rot ### ez mante si ir leide weinen si began ### ich wæn iz hete Hagene ir ze reizen getan
###### 1826 | ### Volker der vil chvene zoch naher vf der banch ### einen videlbogen <starchen> michel vn– lanch ### gelich eime starpfen swerte vil lieht vn– breit ### do sazen vnervorhten die zwene degene gemeit
| ### Nv dvhten sich so here die zwene chvne man ### daz si niht enwolden von dem sedele stan ### dvrch deheine vorhte des gie in an den fvz ### div edel kuniginne vn– bot in vintlichen grvoz
###### 1828 | ### Si sprach nv sagt mir Hagene wer hat nach iv gesant ### daz ir getorstet riten her in dizze lant ### zvo also starchen leiden vn– ich von iv han ### het ir rehte sinne so het irz pilliche lan
###### 1829 | ### Nach mir ensande niemen sprach do Hagene ### man ladet her ze lande drie degene ### die heizent mine herren so bin ich ir man ### deheiner hovereise bin ich vil selten ir bestan
###### 1830 | ### Si sprach nv saget mir mere warvmbe tat ir daz ### daz ir daz habt verdienet daz ich iv bin gehaz ### ir slvget Sivride den minen lieben man ### des ich vnz an min ende immer gnvoc ze weinen han
###### 1831 | ### Waz sol der rede mere sprach er ir ist genvoc ### ich binz et aber Hagene der Sivriden slvoc ### einen helt ze sinen handen wie sere er des engalt ### daz div frowe Chriemh' den schonen Prvnh' schalt
###### 1832 | ### Ez ist et ane lovgen kuniginne rich ### ich han is alles schulde des schaden schedelich ### nv rechez swer der welle ez si wip oder man ### ihn wolde danne liegen ich han iv leides vil getan
| ### Si sprach nv hoert ir rechen wa er mir lovgent niht ### aller miner leide swaz im da von geschiht ### daz sol mir sin vnmære ir Ezeln man ### die vber mveten degene sahen vaste ein ander an
###### 1834 | ### Swer den strit da hvebe so wêre da geschehn ### daz man den zwein gesellen der eren mvese iehn ### wan siz in stvrmen heten vil dicke wol getan ### des sich iene vermazen dvrch vorhte mvsen si daz lan
###### 1835 | ### Do sprach ein der reche wes seht ir mich an ### daz ich ê da lobte des wil ich ab gan ### dvrch niemannes gabe verliesen minen lip ### ia wil vns verleiten des kunic Ezeln wip
###### 1836 | ### Do sprach aber ein ander des selben han ich mvot ### der mir gæbe tverne von rotem golde gvot ### disen videlære woldeich niht bestan ### dvrch sine swinde bliche die ich an im gesehn han
###### 1837 | ### Ovch erchenne ich Hagenen von sinen iungen tagen ### des mach man von dem rechen lihte mir gesagen [65r] ### in zwein vn– zweinzech stvrmen han ich in gesehn ### da vil maniger frowen ist hercenleide geschehn
###### 1838 | ### Er vnt der von Spane die traten manigen stic ### do si hie bi Ezelen vahten manigen wic ### zen eren dem kunige des ist von im vil geschehn ### dar vmbe mvoz man Hagene der eren wol von schulden iehen
###### 1839 | ### Dannoch was der reche siner iar ein kint ### daz do tvmben waren wie grise die nv sint ### nv ist er chomen ze wizzen vn– ist ein grimmech man ### ovch treit er Palmungen da vor <enchvnde> niht <gestan>
| ### Da mite was gescheiden daz da niemen streit ### do wart der chvniginne vil hercenliche leit ### die helde cherten dannen ia vorhten si den tot ### von dem videlære des gie in wærliche not
###### 1841 | ### Do sprach der chvne Volker wir han daz wol ersehn ### daz wir hie <viende> vinden als wir ê horten iehn ### wir svln zv den kunigen hin ze hove gan ### sone tar vnser herren mit strite niemen bestan
###### 1842 | ### Wie diche man durch vorhte manigiv dinch verlat ### swa so frivnt frivnde frivntlich gestat ### vn– hat er gvte sinne daz erz wisliche tvot ### schade vil maniges mannes wirt von sinnen wol behvot
###### 1843 | ### Nv wil ich iv volgen sprach do Hagene ### si giengen da si fvnden vil der degene ### in grozem antpfange noch an dem hove stan ### Volker der vil chvene lvote rvefen began
###### 1844 | ### Er sprach zv sinen herren wie lange welt ir sten ### daz ir ivch lazet dringen ir svlt ze hove gen ### vn– hoeret an dem kunige wi der si gemvot ### do sah man gesellen sich die helde chven vn– gvot
| ### Der fvrste von Berne der nam an die hant ### Gunthern der richen von Burgonden lant ### Irenvrit Gernoten einen chvenen man ### do sah man Giselheren ze hove mit sinem sweher gan
###### 1846 | ### Swie iemen sich gesellete vn– ovch ze hove gie ### Volker vn– Hagene geschieden sich nie ### niwan in eime stvrme an ir endes zit ### daz mvsen beweinen vil schone iuncfrowen sit
###### 1847 | ### Do sach man mit den kunigen hin ze hove gan ### ir edeln ingesindes tvsent chuner man ### dar vber sehzech rechen mit in warn chomen ### die het in sime lande der chvene Hagen genomen
###### 1848 | ### Hawart vn– ovch Irinch zwene vz erwelte man ### die sah man frivntliche bi den kunigen gan ### Danchwart vn– Wolfhart die heten sich bewegen ### man sach si grozer tvgende in ir vbermvte pflegn
| ### Do der vogt von Rine in den palas gie ### Ezele der riche daz niht langer lie ### er spranch von sime sedele als er si chomen sach ### ein grvoz so rehte schone von kunige nie mer geschach
###### 1850 | ### Sit willechomen her Gunther vn– ovch her Gernot ### vn– iwer brvder Giselher dem ich min dienst enbot ### mit triwen vlizzechli[65v]che ze Wormez vber Rin ### vn– allez daz gedigene sol mir willechomen sin
###### 1851 | ### Nv sit vns groz willechomen ir zwene degene ### Volker der chuone vn– ovch her Hagene ### mir vn– miner frowen her in dizze lant ### si hat in grozen triwen vil diche mich vmbe ivch gemant
###### 1852 | ### Do sprach der starche Hagene daz haben wir wol vernomen ### wær ich durch mine herren zen Hvnen niht bechomen ### so wær ich iv zen eren geriten in daz lant ### do nam der wirt vil edele die lieben geste zehant
###### 1853 | ### vn– brahte si zem sedele da er selbe saz ### do schancte man den gesten mit vlize tet man daz ### in witen goldes schalen moraz vn– win ### vn– bat die ellenden groze willechomen sin
| ### Do sprach der kunic der Hunin des wil ich iv veriehn ### mirn enchvnde in disen citen lieber niht geschehn ### denne ovch an iv rechen daz ir vns her sit chomen ### des ist miner frowen michel trvren benomen
###### 1855 | ### Mich nimt des michel wnder waz ich iv habe getan ### so manigen gast vil edelen den ich gewnnen han ### daz ir nie chomen rvochet her in miniv lant ### daz ich ivch nv gesehn han daz ist zen vrevden mir gewant
###### 1856 | ### Des antwrt Rvdeger ein ritter hoch gemvot ### ir mveget si sehn gerne ir triwe div ist gvot ### der miner frowen mage so schone chvnnen pflegen ### si bringent iv ze hvse vil manigen wætlichen degen
###### 1857 | ### An svnewenden abent als wir han vernomen ### waren si ze <Ezelen> bverge dem chvnige ze hvse chomen ### ein wirt nie sine geste so minneklich enpfie ### dar nach er zv den tischen mit in vil vroliche gie
| ### Ein kunec bi sinen gesten schoner nie gesaz ### man gab in vollechliche trinchen vn– maz ### vn– allez daz si wolden des was man in bereit ### man hete von den degenen vil michel wnder geseit
| ### Ezele der riche het an <bow> geleit ### sinen vliz kostenliche mit grozer arebeit ### palas un– tvrne kemenaten ane zal ### in einer witen burge vn– einen herlichen sal
###### 1860 | ### Den het er heizen bowen lanch hoch vn– wit ### dvrch daz so vil der rechen in svhte zaller cit ### an ander sin gesinde zwelf riche kunige her ### vn– vil der werden degene het er zallen citen mer
###### 1861 | ### denne ir kvnic ie gewnne als ich vernomen han ### er lebt in hoher wnne von magen vn– man ### schallen vn– dringen het der fvrste gvot ### von manigem snellem degene des stvont im hohe der mvot

<<< Übersicht <<< vorige Seite nächste Seite >>>